@@ -109,6 +109,12 @@
 #'   See [add_github_actions_citation()] for further information. 
 #'   
 #'   If `create_repo = FALSE` this argument is ignored.
+#'   
+#' @param gh_codemeta A logical value. If `TRUE` (default) configures GitHub 
+#'   Actions to automatically update the `codemeta.json` file. 
+#'   See [add_github_actions_codemeta()] for further information. 
+#'   
+#'   If `create_repo = FALSE` this argument is ignored.
 #' 
 #' @param codecov A logical value. If `TRUE` (default) configures GitHub 
 #'   Actions to automatically report the code coverage of units tests after 
@@ -299,9 +305,10 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
                         code_of_conduct = TRUE, vignette = TRUE, 
                         test = TRUE, create_repo = TRUE, private = FALSE, 
                         gh_check = TRUE, codecov = TRUE, website = TRUE, 
-                        gh_render = TRUE, gh_citation = TRUE, given = NULL, 
-                        family = NULL, email = NULL, orcid = NULL, 
-                        organisation = NULL, overwrite = FALSE, quiet = FALSE) {
+                        gh_render = TRUE, gh_citation = TRUE, 
+                        gh_codemeta = TRUE, given = NULL, family = NULL, 
+                        email = NULL, orcid = NULL, organisation = NULL, 
+                        overwrite = FALSE, quiet = FALSE) {
   
   
   ## If not RStudio ----
@@ -418,6 +425,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     website     <- FALSE
     gh_render   <- FALSE
     gh_citation <- FALSE
+    gh_codemeta <- FALSE
   }
   
   
@@ -500,7 +508,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
   add_to_buildignore(".Rproj.user", quiet = quiet)
   add_to_buildignore(".DS_Store", quiet = quiet)
   
-  if (!quiet) ui_line()
+  if (!quiet) cli::cat_line()
   
   
   ## Create DESCRIPTION ----
@@ -508,14 +516,14 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
   add_description(given, family, email, orcid, organisation, open = FALSE, 
                   overwrite = overwrite, quiet = quiet)
   
-  if (!quiet) ui_line()
+  if (!quiet) cli::cat_line()
   
   
   ## Add LICENSE ----
   
   add_license(license, given, family, quiet = quiet)
   
-  if (!quiet) ui_line()
+  if (!quiet) cli::cat_line()
   
   
   ## Create folders ----
@@ -529,7 +537,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
   
   if (!quiet) ui_done("Creating {ui_value('man/')} directory")
   
-  if (!quiet) ui_line()
+  if (!quiet) cli::cat_line()
   
   
   ## Package doc bonus ----
@@ -551,7 +559,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
                 overwrite = overwrite)) 
   }
   
-  if (!quiet) ui_line()
+  if (!quiet) cli::cat_line()
   if (!quiet) ui_done("Writing {ui_value('R/fun-demo.R')} file")
   
   suppressMessages(devtools::document(quiet = TRUE))
@@ -752,7 +760,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     
     add_github_actions_pkgdown()
     
-    ui_line()
+    cli::cat_line()
     
     usethis::use_github_pages(branch = "gh-pages")
   }
@@ -774,13 +782,29 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
 
   
   
+  ##
+  ## GHA CODEMETA ----
+  ## 
+  
+  
+  
+  if (gh_codemeta) {
+    
+    ui_title("Configuring GH Actions - codemeta.json")
+    
+    add_github_actions_codemeta(quiet = quiet)
+  }
+
+  
+
   ##
   ## SECOND COMMIT ----
   ## 
   
   
   
-  if (gh_check || codecov || gh_render || website || gh_citation) {
+  if (gh_check || codecov || gh_render || website || gh_citation || 
+      gh_codemeta) {
     
     ui_title("Committing changes")
     
@@ -890,7 +914,7 @@ new_package <- function(license = "GPL (>= 2)", status = NULL,
     ui_todo(paste0("Write your units tests in the ", 
                    "{ui_value('tests/testthat/')} directory"))
   
-  ui_line()
+  cli::cat_line()
   
   ui_todo("...and commit your changes!")
   
