@@ -67,12 +67,14 @@ get_deps_in_functions_r <- function() {
     
     ## Attached Packages ----
     
-    pattern <- c(paste0("library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
-                 paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    pattern <- c(
+      paste0("(^|\\s{1,})library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
+      paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    
     pattern <- paste0(pattern, collapse = "|")
     
     pkgs <- unlist(lapply(x, function(x) {
@@ -227,12 +229,14 @@ get_deps_in_examples <- function() {
     
     ## Attached Packages ----
     
-    pattern <- c(paste0("library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
-                 paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    pattern <- c(
+      paste0("(^|\\s{1,})library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
+      paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    
     pattern <- paste0(pattern, collapse = "|")
     
     pkgs <- unlist(lapply(x, function(x) {
@@ -289,7 +293,7 @@ get_deps_extra <- function(compendium = NULL) {
   if (!dir.exists(path)) return(NULL)
   
   x <- list.files(path, 
-                  pattern = "\\.R$|\\.Rmd$", full.names = TRUE, 
+                  pattern = "\\.R$|\\.Rmd$|\\.qmd$", full.names = TRUE, 
                   ignore.case = TRUE, recursive = TRUE)
   
   pos <- grep(paste0(.Platform$file.sep, 
@@ -342,12 +346,14 @@ get_deps_extra <- function(compendium = NULL) {
     
     ## Attached Packages ----
     
-    pattern <- c(paste0("library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
-                 paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    pattern <- c(
+      paste0("(^|\\s{1,})library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
+      paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    
     pattern <- paste0(pattern, collapse = "|")
     
     pkgs <- unlist(lapply(x, function(x) {
@@ -365,7 +371,7 @@ get_deps_extra <- function(compendium = NULL) {
     
     ## Check if .Rmd ----
     
-    x <- list.files(path, pattern = "\\.Rmd$", 
+    x <- list.files(path, pattern = "\\.Rmd$|\\.qmd$", 
                     full.names = TRUE, ignore.case = TRUE, recursive = TRUE)
     
     pos <- grep(paste0(.Platform$file.sep, 
@@ -414,7 +420,7 @@ get_deps_in_vignettes <- function() {
   }
   
   x <- list.files(path = file.path(path, "vignettes"), 
-                  pattern = "\\.R$|\\.Rmd$", full.names = TRUE, 
+                  pattern = "\\.R$|\\.Rmd$|\\.qmd$", full.names = TRUE, 
                   ignore.case = TRUE, recursive = TRUE)
   
   if (!length(x)) {
@@ -470,12 +476,14 @@ get_deps_in_vignettes <- function() {
     
     ## Attached Packages ----
     
-    pattern <- c(paste0("library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
-                 paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    pattern <- c(
+      paste0("(^|\\s{1,})library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
+      paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    
     pattern <- paste0(pattern, collapse = "|")
     
     pkgs <- unlist(lapply(x, function(x) {
@@ -493,8 +501,9 @@ get_deps_in_vignettes <- function() {
     
     ## Check if .Rmd ----
     
-    x <- list.files(path = file.path(path, "vignettes"), pattern = "\\.Rmd$", 
-                    full.names = TRUE, ignore.case = TRUE, recursive = TRUE)
+    x <- list.files(path = file.path(path, "vignettes"), 
+                    pattern = "\\.Rmd$|\\.qmd$", full.names = TRUE, 
+                    ignore.case = TRUE, recursive = TRUE)
     
     if (length(x)) funs <- sort(unique(c(funs, "knitr", "rmarkdown")))
     
@@ -582,12 +591,14 @@ get_deps_in_tests <- function() {
     
     ## Attached Packages ----
     
-    pattern <- c(paste0("library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
-                 paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
-                        "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
-                        "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    pattern <- c(
+      paste0("(^|\\s{1,})library\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"),
+      paste0("require\\s{0,}\\(\\s{0,}([A-Z|a-z|0-9|\\.]{1,}|",
+             "\"\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\"|",
+             "\'\\s{0,}[A-Z|a-z|0-9|\\.]{1,}\\s{0,}\')"))
+    
     pattern <- paste0(pattern, collapse = "|")
     
     pkgs <- unlist(lapply(x, function(x) {
